* --------------------------------------------------------------------
* Project: The Effect of Information and Communication Technologies
*          on Urban Structure 
*          published in: Economic Policy, April 2008, pp. 201 - 242
* Authors: Yannis M. Ioannides, Henry G. Overman, 
*          Esteban Rossi-Hansberg, and Kurt Schmidheiny 
* Date:    December 7, 2007
* File:    onestep.do
* Title:   Creates the dataset onestep.dta
*          used for estimations in Tables 6 and 7
* --------------------------------------------------------------------

set more off
clear
set mem 16m

* --------------------------------------------------------------------
* use countrydata
* --------------------------------------------------------------------

use countries.dta, clear
sort countrycode year

* --------------------------------------------------------------------
* create country-year identifier
* --------------------------------------------------------------------

generate countryyear = countryid*10000+year
lab var countryyear "= countryid*10000+year"

* --------------------------------------------------------------------
* create new country variables
* --------------------------------------------------------------------

generate phones_sc = phones/1000
lab var phones_sc "= phones/1000"

generate lphones_sc = ln(phones_sc)
lab var lphones_sc "= ln(phones_sc)"

generate internet_sc = internet/1000
lab var internet_sc "= internet/1000"

generate linternet_sc = ln(internet_sc)
lab var linternet_sc "= ln(internet_sc)"

generate nonagriva = (1-agriva)
lab var nonagriva "= (1-agriva)"

generate lnarea = log(landarea)
lab var lnarea "= log(landarea)"

generate lngdppcppp = log(gdppcppp)
lab var lngdppcppp "= log(gdppcppp)"

tsset countryid year
generate gdpgrowth = lngdppcppp - l.lngdppcppp
lab var gdpgrowth "= lngdppcppp - l.lngdppcppp"

by countryid: egen gdpgrowth_sd = sd(gdpgrowth)
lab var gdpgrowth_sd "= sd(gdpgrowth), by country"

generate roaddens = (roads/landarea)*100
lab var roaddens "= (roads/landarea)*100"

generate invroaddens = 1/roaddens 
lab var invroaddens "= 1/roaddens"

generate lnpop = log(pop)
lab var lnpop "= log(pop)"

generate govexp_mix = govexp
replace  govexp_mix = govexp_ktsoo if govexp == .
lab var govexp_mix "= govexp | = govexp_ktsoo if govexp == ."

generate time = year - 1980
lab var time "= year - 1980"

replace monopubyear = 1980 if monopubyear == -1
replace monopubyear = 2001 if monopubyear == 9999
generate monopubtime = monopubyear - 1980
generate timeaftermonopub = (time - monopubtime)*((time - monopubtime)>0)
lab var timeaftermonopub "years after end public monopoly"
drop monopubtime

replace monoprivyear = 1980 if monoprivyear == -1
replace monoprivyear = 2001 if monoprivyear == 9999
generate monoprivtime = monoprivyear - 1980
generate timeaftermonopriv = (time - monoprivtime)*((time - monoprivtime)>0)
lab var timeaftermonopriv "years after end private monopoly"
drop monoprivtime

aorder oecdyear - govexp_mix
order countrycode - oceania

* --------------------------------------------------------------------
* merge city data
* --------------------------------------------------------------------

sort countrycode year
merge countrycode year using cities.dta, nokeep
drop _merge

drop if missing(popcity)

sort countrycode year cityid
order countrycode year countryyear countryname countryid cityid cityname statename

* --------------------------------------------------------------------
* apply threshold
* --------------------------------------------------------------------

drop if popcity < threshold

* --------------------------------------------------------------------
* generate rank of city
* --------------------------------------------------------------------

* rank cities by population
drop if popcity == .
bysort countryid year: egen rank=rank(-popcity)
sort countrycode year rank

* calculate logs
generate lnrank = log(rank)
lab var lnrank "= log(rank)"

generate lnrank05 = log(rank-0.5)
lab var lnrank05 "= log(rank-0.5)"

generate lnpopc = log(popcity)
lab var lnpopc "= log(popcity)"

bysort countryid year: egen obs = count(popcity)
lab var obs "number of cities in country and year"

* --------------------------------------------------------------------
* normalize city size, 
* divide by total country population
* --------------------------------------------------------------------

generate popcnorm = popcity/pop
move popcnorm africa
lab var popcnorm "= popcity/pop"

generate lnpopcnorm = log(popcnorm)
move lnpopcnorm africa
lab var lnpopcnorm "= log(popcnorm)"

* --------------------------------------------------------------------
* create interaction variables
* --------------------------------------------------------------------

egen average = mean(log(phones_sc))
generate lphon2lpopcn = (log(phones_sc)-average) * lnpopcnorm
lab var lphon2lpopcn "= (log(phones_sc)-average) * lnpopcnorm"
drop average

egen average = mean(log(internet_sc))
generate linet2lpopcn = (log(internet_sc)-average) * lnpopcnorm
lab var linet2lpopcn "= (log(internet_sc)-average) * lnpopcnorm"
drop average

egen average = mean(invroaddens)
generate ird2lpopcn = (invroaddens-average) * lnpopcnorm
lab var ird2lpopcn "= (invroaddens-average) * lnpopcnorm"
drop average

egen average = mean(lnpop)
generate lpop2lpopcn = (lnpop-average) * lnpopcnorm
lab var lpop2lpopcn "= (lnpop-average) * lnpopcnorm"
drop average

egen average = mean(lngdppcppp)
generate lgdpp2lpopcn = (lngdppcppp-average) * lnpopcnorm
lab var lgdpp2lpopcn "= (lngdppcppp-average) * lnpopcnorm"
drop average

egen average = mean(trade)
generate trade2lpopcn = (trade-average) * lnpopcnorm
lab var trade2lpopcn "= (trade-average) * lnpopcnorm"
drop average

egen average = mean(nonagriva)
generate nonagr2lpopcn = (nonagriva-average) * lnpopcnorm
lab var nonagr2lpopcn "= (nonagriva-average) * lnpopcnorm"
drop average

egen average = mean(gdpgrowth_sd)
generate gdpsd2lpopcn = (gdpgrowth_sd-average) * lnpopcnorm
lab var gdpsd2lpopcn "= (gdpgrowth_sd-average) * lnpopcnorm"
drop average

egen average = mean(lnarea)
generate larea2lpopcn = (lnarea-average) * lnpopcnorm
lab var larea2lpopcn "= (lnarea-average) * lnpopcnorm"
drop average

generate monopu2lpopcn = monopub * lnpopcnorm
lab var monopu2lpopcn "= monopub * lnpopcnorm"

generate monopr2lpopcn = monopriv * lnpopcnorm
lab var monopr2lpopcn "= monopriv * lnpopcnorm"

generate timemonopu2lpopcn = timeaftermonopub  * lnpopcnorm
lab var timemonopu2lpopcn "= timeaftermonopub  * lnpopcnorm"

generate timemonopr2lpopcn = timeaftermonopriv * lnpopcnorm
lab var timemonopr2lpopcn "= timeaftermonopriv * lnpopcnorm"

generate eu2lpopcn = eu*lnpopcnorm
lab var  eu2lpopcn "= eu*lnpopcnorm"

generate nafta2lpopcn = nafta*lnpopcnorm
lab var  nafta2lpopcn "= nafta*lnpopcnorm"

generate time2lpopcn = time * lnpopcnorm
lab var time2lpopcn "= time * lnpopcnorm"

by countryid: egen govexp_avgpan = mean(govexp_mix)
lab var govexp_avgpan "=  mean(govexp_mix), years with city observations"

egen average = mean(govexp_avgpan)
generate govavgpan2lpopcn = (govexp_avgpan-average) * lnpopcnorm
lab var govavgpan2lpopcn "= (govexp_avgpan-average) * lnpopcnorm"
drop average

by countryid: egen obs_avgpan = mean(obs)
lab var obs_avgpan "=  mean(obs), years with city observations"

egen average = mean(obs_avgpan/1000)
generate obsavgpan2lpopcn = (obs_avgpan/1000-average) * lnpopcnorm
lab var obsavgpan2lpopcn "= (obs_avgpan/1000-average) * lnpopcnorm"
drop average

* --------------------------------------------------------------------
* save data
* --------------------------------------------------------------------

save onestep.dta, replace




